@@ -5,7 +5,7 @@ from stl_sdk.exceptions import InvalidInitParameters
 class TorpedoClientFlask(TorpedoClient):
     """Cliente Flask para comunicação com Torpedo.
         Ao iniciar o cliente ele irá buscar as variaveis de ambiente
-        `TORPEDO_URL` e `CLIENT_NAME`
+        `TORPEDO_URL` e `TORPEDO_PRODUCT_NAME`
 
     Exemplo:
 
@@ -21,14 +21,14 @@ class TorpedoClientFlask(TorpedoClient):
     """
 
     def __init__(self, app=None):
-        self.app = app
         if app is not None:
             self.init_app(app)
-        super().__init__()
 
     def init_app(self, app):
-        self.torpedo_url = app.config['TORPEDO_URL']
-        self.client_name = app.config['CLIENT_NAME']
+        if app.config['TORPEDO_URL'] is None:
+            raise InvalidInitParameters('Missing TORPEDO_URL on TorpedoClientFlask initialization.')
 
-        if self.client_name is None:
-            raise InvalidInitParameters('Missing CLIENT_NAME on TorpedoClient initialization.')
+        if app.config['TORPEDO_PRODUCT_NAME'] is None:
+            raise InvalidInitParameters('Missing TORPEDO_PRODUCT_NAME on TorpedoClientFlask initialization.')
+
+        super().__init__(app.config['TORPEDO_URL'], app.config['TORPEDO_PRODUCT_NAME'])
