@@ -7,12 +7,12 @@ from . import VERSION
 class WavesClient:
     """Cliente HTTP para comunicação com Waves
 
-    :param str waves_url: Endereço da API do Waves
+    :param str url: Endereço da API do Waves
     :param str api_key: Chave de API para autenticação
     """
 
-    def __init__(self, waves_url, api_key):
-        self.waves_url = waves_url.strip('/')
+    def __init__(self, url, api_key):
+        self.url = url.strip('/')
         self.api_key = api_key
 
     def get_workflow(self, identifier):
@@ -34,7 +34,7 @@ class WavesClient:
         """
         try:
             response = requests.get(
-                '{}/api/workflows/{}'.format(self.waves_url, identifier),
+                '{}/api/workflows/{}'.format(self.url, identifier),
                 headers=self._get_headers(),
             )
             response.raise_for_status()
@@ -64,7 +64,7 @@ class WavesClient:
         """
         try:
             response = requests.post(
-                '{}/api/workflows'.format(self.waves_url),
+                '{}/api/workflows'.format(self.url),
                 headers=self._get_headers(),
                 json=workflow)
             response.raise_for_status()
@@ -91,7 +91,7 @@ class WavesClient:
         """
         try:
             response = requests.put(
-                '{}/api/workflows/{}/archive'.format(self.waves_url, identifier),
+                '{}/api/workflows/{}/archive'.format(self.url, identifier),
                 headers=self._get_headers())
             response.raise_for_status()
             return response.json()
@@ -117,7 +117,7 @@ class WavesClient:
         """
         try:
             response = requests.put(
-                '{}/api/workflows/{}/unarchive'.format(self.waves_url, identifier),
+                '{}/api/workflows/{}/unarchive'.format(self.url, identifier),
                 headers=self._get_headers())
             response.raise_for_status()
             return response.json()
@@ -151,7 +151,7 @@ class WavesClient:
         """
         try:
             response = requests.get(
-                '{}/api/executions'.format(self.waves_url),
+                '{}/api/executions'.format(self.url),
                 headers=self._get_headers(),
                 params={
                     'term': term,
@@ -185,7 +185,7 @@ class WavesClient:
         """
         try:
             response = requests.get(
-                '{}/api/executions/{}'.format(self.waves_url, identifier),
+                '{}/api/executions/{}'.format(self.url, identifier),
                 headers=self._get_headers(),
             )
             response.raise_for_status()
@@ -216,7 +216,7 @@ class WavesClient:
         """
         try:
             response = requests.post(
-                '{}/api/executions'.format(self.waves_url),
+                '{}/api/executions'.format(self.url),
                 headers=self._get_headers(),
                 json={
                     "workflow_identifier": workflow_identifier,
@@ -249,7 +249,7 @@ class WavesClient:
         """
         try:
             response = requests.put(
-                '{}/api/executions/{}'.format(self.waves_url, identifier),
+                '{}/api/executions/{}'.format(self.url, identifier),
                 headers=self._get_headers(),
                 json={
                     "description": description
@@ -276,7 +276,7 @@ class WavesClient:
         """
         try:
             response = requests.delete(
-                '{}/api/executions/{}'.format(self.waves_url, identifier),
+                '{}/api/executions/{}'.format(self.url, identifier),
                 headers=self._get_headers())
             response.raise_for_status()
         except HTTPError as error:
@@ -304,7 +304,7 @@ class WavesClient:
         """
         try:
             response = requests.post(
-                '{}/api/business-tasks'.format(self.waves_url),
+                '{}/api/business-tasks'.format(self.url),
                 headers=self._get_headers(),
                 json=btask)
             response.raise_for_status()
@@ -331,7 +331,7 @@ class WavesClient:
         """
         try:
             response = requests.put(
-                '{}/api/business-tasks/{}/publish'.format(self.waves_url, identifier),
+                '{}/api/business-tasks/{}/publish'.format(self.url, identifier),
                 headers=self._get_headers())
             response.raise_for_status()
             return response.json()
@@ -357,7 +357,7 @@ class WavesClient:
         """
         try:
             response = requests.put(
-                '{}/api/business-tasks/{}/unpublish'.format(self.waves_url, identifier),
+                '{}/api/business-tasks/{}/unpublish'.format(self.url, identifier),
                 headers=self._get_headers())
             response.raise_for_status()
             return response.json()
@@ -381,7 +381,7 @@ class WavesClient:
         """
         try:
             response = requests.get(
-                '{}/api/workers'.format(self.waves_url),
+                '{}/api/workers'.format(self.url),
                 headers=self._get_headers(),
             )
             response.raise_for_status()
